#!/bin/zsh

# Process: Run individual samples through W0 addition and Matthews (not Full length)

# cd ~/OneDrive\ -\ Imperial\ College\ London/_Data/RNA-seq-robOnedrive/Nanopore_RNA-seq
# permissions with chmod u+x _Paper_analysis/vs_self_output/Paper_vsself_single_files.sh
# run with ./_Paper_analysis/vs_self_output/Paper_vsself_single_files.sh


# starting files: (was _Paper_analysis/vs_self_output/SAM_files/AllvsSelf_sort.bam)  _Paper_analysis/vs_self_output/SAM_files/M11-MJ2vsSelf_sort.bam  _Paper_analysis/vs_self_output/SAM_files/M11-AJ2-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/WTw-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/HB9-self_sort.bam
# replace M11-MJ2vsSelf with other files vsSelf or vsWTw for that version.
# replace Single_samples/M11-MJ2 with new sample ID; replace M11-MJ2vsSelf with IDvsSelf or vsSelf to vsWTw
# replace vs_self_output with final destination folder.


# Analysis of M11-MJ2 sample START

mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2

# Bring in the Bam file and index from the minimap output from allvsSelf files part 1. Should be free of secondary reads etc
cp -f _Paper_analysis/vs_self_output/SAM_files/M11-MJ2vsSelf_sort.bam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_sort.bam
cp -f _Paper_analysis/vs_self_output/SAM_files/M11-MJ2vsSelf_sort.bam.bai _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_sort.bam.bai


#Now make sure it contains unique reads only
samtools view -F 2304 -b _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_sort.bam > _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.bam
samtools index -b _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.bam

#report mapped reads
echo " Mapped Unique reads in M11-MJ2vsSelf = "
samtools view -c -F 260 _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.bam
#Output - Mapped reads in M11-MJ2 vs Self= 906

#Convert to headered SAM 
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.sam

# generate directory structure for storing various sam outputs.
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_3p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_5p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_ends_not_assigned
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_full_length
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out


# Rscript ./Aaron_script/transcript_variation_calculation_runfirst.r ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq_trim.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_First/M11-MJ2vsSelf ./EBV_annotations/HB9_166754_2023/MR11_oriPMlu.fa ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 5 20 2

Rscript ./Aaron_script/W0_correcting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_unq.sam ./EBV_annotations/EBV_annotations_paper/EBNAexons_pHB9_oriPMlu.bed


# version 2 script does not include a destination folder prefix, so need to move the files to desired folder.
mv updated_M11-MJ2vsSelf_unq.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.sam
mv candidates_W0_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first/M11-MJ2vsSelf_candidates_W0_id.sam
mv candidates_mixed_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first/M11-MJ2vsSelf_candidates_mixed_id.sam
mv candidates_W2_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first/M11-MJ2vsSelf_candidates_W2_id.sam
mv candidates_unassigned_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first/M11-MJ2vsSelf_candidates_unassigned_id.sam
# mv candidates_unassigned_id.log ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_first/M11-MJ2vsSelf_candidates_unassigned_id.log


# sort and index the full size bam file that has W0 corrections. Aaron suggests that this may be redundant, but not taking chances since I have the code.
samtools view -b ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.sam > ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.bam
samtools sort ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.bam
samtools index ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.bam
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.sam
# remove intermediates
rm ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.sam
rm ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_corrected.bam





# Now classify the scripts according to whether they are full length. This does not include pA or mRNA starts extracted from gff3 or similar files, which is the only feature that we really want to add. THen can get more stringent to exclude broken reads.
# Syntax of command: input_sam ID; window_size; No_of_reads_required_to_define_cluster; Window_capture_stage_2; Window_stage_3 [note: what is the difference here?] . 
Rscript ./Aaron_script/transcript_classifying.r ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.sam 2 3 20 20

# merge the outputs from Aaron's first script back into a single file, which now has the * column at the end (x_dotcol.sam)
#cat _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_W0_3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_W0_5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_W0_full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_W0_unassigned_reads.sam > _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/M11-MJ2vsSelf_W0_dotcol.sam
# move files - will overwrite files of same name

 mv 3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_3p_intact/M11-MJ2vsSelf_3p_intact_transcripts.sam
 mv 5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_5p_intact/M11-MJ2vsSelf_5p_intact_transcripts.sam
 mv unassigned.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_ends_not_assigned/M11-MJ2vsSelf_unassigned.sam
 mv full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_full_length/M11-MJ2vsSelf_full_length_transcripts.sam


# Run script for repeat counting
# command syntax: input_sam; Exon_bed_file (requires C, W and Y exons. Others optional); Window for 5' and 3' exon position variability [need to check what this means]; Window size for tolerance of exon position changes 
# note that we have increased the last variable to 3 as this copes with the variation of the W2del21 exon splice donor to del24, without compromising W1/W1'

Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/IR1_analysis
mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/IR1_analysis/M11-MJ2vsSelf_allReads_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/IR1_analysis/M11-MJ2vsSelf_allReads_IR1_repeat_counts.txt

# re-run repeat counting for full-length reads only (probably makes little difference)
Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_full_length/M11-MJ2vsSelf_full_length_transcripts.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/IR1_analysis/M11-MJ2vsSelf_fulllength_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/IR1_analysis/M11-MJ2vsSelf_fulllength_IR1_repeat_counts.txt


# Run the Matthews script 1. Uses nanopolish output fromt he AllvsSelf analysis part 2 script. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/1_M11-MJ2vsSelf_W0_AllReads 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80


# Run the Matthews script 2. prefix for script 2 does not tolerate folder prefix so need to move files from top level folder after script has run
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_M11-MJ2vsSelf_W0_AllReads 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/1_M11-MJ2vsSelf_W0_AllReads.start_sad_stop_pattern_count.txt

mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.proteins_not_known.fasta
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.proteins_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.proteins_known.fasta
# rm _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc
cp -r 2_M11-MJ2vsSelf_W0_AllReads_ssc  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/
rm -rf 2_M11-MJ2vsSelf_W0_AllReads_ssc
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.count_of_translated_features.txt  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.count_of_translated_features.txt
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt
mv 2_M11-MJ2vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt


# run the script to make files of reads sorted by pA site: Syntax: input.sam minimum_mapq_quality_value max_5'_softclip Max_3'_softclip Max_no_pA_sites_output +/-window_size Fasta_file
# have tweaked the pA window up to 40 as there are a few pA sites that have this variation.
perl Matthews_script/all_transcripts_grouped_by_polya.pl _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_all_reads/M11-MJ2vsSelf_W0_sort.sam 1 100 10 25 50 EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa
mkdir _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/pA_SAM_allReads
mv -f polya_group_* _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/pA_SAM_allReads


# Run the Matthews script 1 for full length reads only. Amend prefix for correct folder. Have changed fa file to MR11 (and prefix) for forst example into script1 and 2 folders, and second command uses nanopolish from pre-W0 appended file. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/1_M11-MJ2vsSelf_W0_fullLength 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/W0_full_length/M11-MJ2vsSelf_full_length_transcripts.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80



# Run the Matthews script 2 for full length reads only. Script does not take folder prefix for output.
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_M11-MJ2vsSelf_W0_fullLength 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/1_M11-MJ2vsSelf_W0_fullLength.start_sad_stop_pattern_count.txt


mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.proteins_not_known.fasta
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.proteins_known.fasta  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.proteins_known.fasta
cp -r 2_M11-MJ2vsSelf_W0_fullLength_ssc _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/
rm -rf 2_M11-MJ2vsSelf_W0_fullLength_ssc 
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.count_of_translated_features.txt _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.count_of_translated_features.txt
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff  _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt
mv 2_M11-MJ2vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/M11-MJ2/Script_out/2_M11-MJ2vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt


# starting files: (was _Paper_analysis/vs_self_output/SAM_files/AllvsSelf_sort.bam)  _Paper_analysis/vs_self_output/SAM_files/M11-AJ2vsSelf_sort.bam  _Paper_analysis/vs_self_output/SAM_files/M11-AJ2-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/WTw-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/HB9-self_sort.bam
# replace M11-AJ2vsSelf with other files vsSelf or vsWTw for that version.
# replace Single_samples/M11-AJ2 with new sample ID; replace M11-AJ2vsSelf with IDvsSelf or vsSelf to vsWTw
# replace vs_self_output with final destination folder.

# Analysis of M11-MJ2 sample END; M11-AJ2 analysis starts

mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2

# Bring in the Bam file and index from the minimap output from allvsSelf files part 1. Should be free of secondary reads etc
cp -f _Paper_analysis/vs_self_output/SAM_files/M11-AJ2vsSelf_sort.bam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_sort.bam
cp -f _Paper_analysis/vs_self_output/SAM_files/M11-AJ2vsSelf_sort.bam.bai _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_sort.bam.bai


#Now make sure it contains unique reads only
samtools view -F 2304 -b _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_sort.bam > _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.bam
samtools index -b _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.bam

#report mapped reads
echo " Mapped Unique reads in M11-AJ2vsSelf = "
samtools view -c -F 260 _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.bam
#Output - Mapped reads in M11-AJ2 vs Self= 515

#Convert to headered SAM 
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.sam

# generate directory structure for storing various sam outputs.
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_3p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_5p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_ends_not_assigned
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_full_length
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads
mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out


# Rscript ./Aaron_script/transcript_variation_calculation_runfirst.r ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq_trim.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_First/M11-AJ2vsSelf ./EBV_annotations/HB9_166754_2023/MR11_oriPMlu.fa ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 5 20 2

Rscript ./Aaron_script/W0_correcting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_unq.sam ./EBV_annotations/EBV_annotations_paper/EBNAexons_pHB9_oriPMlu.bed


# version 2 script does not include a destination folder prefix, so need to move the files to desired folder.
mv updated_M11-AJ2vsSelf_unq.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.sam
mv candidates_W0_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first/M11-AJ2vsSelf_candidates_W0_id.sam
mv candidates_mixed_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first/M11-AJ2vsSelf_candidates_mixed_id.sam
mv candidates_W2_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first/M11-AJ2vsSelf_candidates_W2_id.sam
mv candidates_unassigned_id.sam ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first/M11-AJ2vsSelf_candidates_unassigned_id.sam
# mv candidates_unassigned_id.log ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_first/M11-AJ2vsSelf_candidates_unassigned_id.log


# sort and index the full size bam file that has W0 corrections. Aaron suggests that this may be redundant, but not taking chances since I have the code.
samtools view -b ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.sam > ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.bam
samtools sort ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.bam
samtools index ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.bam
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.bam > ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.sam
# remove intermediates
rm ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.sam
rm ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_corrected.bam





# Now classify the scripts according to whether they are full length. This does not include pA or mRNA starts extracted from gff3 or similar files, which is the only feature that we really want to add. THen can get more stringent to exclude broken reads.
# Syntax of command: input_sam ID; window_size; No_of_reads_required_to_define_cluster; Window_capture_stage_2; Window_stage_3 [note: what is the difference here?] . 
Rscript ./Aaron_script/transcript_classifying.r ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.sam 2 3 20 20

# merge the outputs from Aaron's first script back into a single file, which now has the * column at the end (x_dotcol.sam)
#cat _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_W0_3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_W0_5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_W0_full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_W0_unassigned_reads.sam > _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/M11-AJ2vsSelf_W0_dotcol.sam
# move files - will overwrite files of same name

 mv 3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_3p_intact/M11-AJ2vsSelf_3p_intact_transcripts.sam
 mv 5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_5p_intact/M11-AJ2vsSelf_5p_intact_transcripts.sam
 mv unassigned.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_ends_not_assigned/M11-AJ2vsSelf_unassigned.sam
 mv full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_full_length/M11-AJ2vsSelf_full_length_transcripts.sam


# Run script for repeat counting
# command syntax: input_sam; Exon_bed_file (requires C, W and Y exons. Others optional); Window for 5' and 3' exon position variability [need to check what this means]; Window size for tolerance of exon position changes 
# note that we have increased the last variable to 3 as this copes with the variation of the W2del21 exon splice donor to del24, without compromising W1/W1'

Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mkdir ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/IR1_analysis
mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/IR1_analysis/M11-AJ2vsSelf_allReads_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/IR1_analysis/M11-AJ2vsSelf_allReads_IR1_repeat_counts.txt

# re-run repeat counting for full-length reads only (probably makes little difference)
Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_full_length/M11-AJ2vsSelf_full_length_transcripts.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/IR1_analysis/M11-AJ2vsSelf_fulllength_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/IR1_analysis/M11-AJ2vsSelf_fulllength_IR1_repeat_counts.txt


# Run the Matthews script 1. Uses nanopolish output fromt he AllvsSelf analysis part 2 script. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/1_M11-AJ2vsSelf_W0_AllReads 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80


# Run the Matthews script 2. prefix for script 2 does not tolerate folder prefix so need to move files from top level folder after script has run
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_M11-AJ2vsSelf_W0_AllReads 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/1_M11-AJ2vsSelf_W0_AllReads.start_sad_stop_pattern_count.txt

mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.proteins_not_known.fasta
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.proteins_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.proteins_known.fasta
# rm _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc
cp -r 2_M11-AJ2vsSelf_W0_AllReads_ssc  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/
rm -rf 2_M11-AJ2vsSelf_W0_AllReads_ssc
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.count_of_translated_features.txt  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.count_of_translated_features.txt
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt
mv 2_M11-AJ2vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt


# run the script to make files of reads sorted by pA site: Syntax: input.sam minimum_mapq_quality_value max_5'_softclip Max_3'_softclip Max_no_pA_sites_output +/-window_size Fasta_file
# have tweaked the pA window up to 40 as there are a few pA sites that have this variation.
perl Matthews_script/all_transcripts_grouped_by_polya.pl _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_all_reads/M11-AJ2vsSelf_W0_sort.sam 1 100 10 25 50 EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa
mkdir _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/pA_SAM_allReads
mv -f polya_group_* _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/pA_SAM_allReads


# Run the Matthews script 1 for full length reads only. Amend prefix for correct folder. Have changed fa file to MR11 (and prefix) for forst example into script1 and 2 folders, and second command uses nanopolish from pre-W0 appended file. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/1_M11-AJ2vsSelf_W0_fullLength 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/W0_full_length/M11-AJ2vsSelf_full_length_transcripts.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80



# Run the Matthews script 2 for full length reads only. Script does not take folder prefix for output.
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_M11-AJ2vsSelf_W0_fullLength 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/1_M11-AJ2vsSelf_W0_fullLength.start_sad_stop_pattern_count.txt


mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.proteins_not_known.fasta
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.proteins_known.fasta  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.proteins_known.fasta
cp -r 2_M11-AJ2vsSelf_W0_fullLength_ssc _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/
rm -rf 2_M11-AJ2vsSelf_W0_fullLength_ssc 
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.count_of_translated_features.txt _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.count_of_translated_features.txt
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff  _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt
mv 2_M11-AJ2vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/M11-AJ2/Script_out/2_M11-AJ2vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt

# starting files: (was _Paper_analysis/vs_self_output/SAM_files/AllvsSelf_sort.bam)  _Paper_analysis/vs_self_output/SAM_files/HB9vsSelf_sort.bam  _Paper_analysis/vs_self_output/SAM_files/HB9-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/WTw-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/HB9-self_sort.bam
# replace HB9vsSelf with other files vsSelf or vsWTw for that version.
# replace Single_samples/HB9 with new sample ID; replace HB9vsSelf with IDvsSelf or vsSelf to vsWTw
# replace vs_self_output with final destination folder.


# Analysis of M11-AJ2 sample END; HB9 analysis starts



mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9

# Bring in the Bam file and index from the minimap output from allvsSelf files part 1. Should be free of secondary reads etc
cp -f _Paper_analysis/vs_self_output/SAM_files/HB9vsSelf_sort.bam _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_sort.bam
cp -f _Paper_analysis/vs_self_output/SAM_files/HB9vsSelf_sort.bam.bai _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_sort.bam.bai


#Now make sure it contains unique reads only
samtools view -F 2304 -b _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_sort.bam > _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.bam
samtools index -b _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.bam

#report mapped reads
echo " Mapped Unique reads in HB9vsSelf = "
samtools view -c -F 260 _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.bam
#Output - Mapped reads in HB9 vs Self= 635

#Convert to headered SAM 
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.bam > ./_Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.sam

# generate directory structure for storing various sam outputs.
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_3p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_5p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_ends_not_assigned
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_full_length
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads
mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/Script_out


# Rscript ./Aaron_script/transcript_variation_calculation_runfirst.r ./_Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq_trim.sam _Paper_analysis/vs_self_output/Single_samples/HB9/W0_First/HB9vsSelf ./EBV_annotations/HB9_166754_2023/MR11_oriPMlu.fa ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 5 20 2

Rscript ./Aaron_script/W0_correcting.r ./_Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_unq.sam ./EBV_annotations/EBV_annotations_paper/EBNAexons_pHB9_oriPMlu.bed


# version 2 script does not include a destination folder prefix, so need to move the files to desired folder.
mv updated_HB9vsSelf_unq.sam ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.sam
mv candidates_W0_id.sam ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first/HB9vsSelf_candidates_W0_id.sam
mv candidates_mixed_id.sam ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first/HB9vsSelf_candidates_mixed_id.sam
mv candidates_W2_id.sam ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first/HB9vsSelf_candidates_W2_id.sam
mv candidates_unassigned_id.sam ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first/HB9vsSelf_candidates_unassigned_id.sam
# mv candidates_unassigned_id.log ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_first/HB9vsSelf_candidates_unassigned_id.log


# sort and index the full size bam file that has W0 corrections. Aaron suggests that this may be redundant, but not taking chances since I have the code.
samtools view -b ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.sam > ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.bam
samtools sort ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.bam > ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.bam
samtools index ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.bam
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.bam > ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.sam
# remove intermediates
rm ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.sam
rm ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_corrected.bam





# Now classify the scripts according to whether they are full length. This does not include pA or mRNA starts extracted from gff3 or similar files, which is the only feature that we really want to add. THen can get more stringent to exclude broken reads.
# Syntax of command: input_sam ID; window_size; No_of_reads_required_to_define_cluster; Window_capture_stage_2; Window_stage_3 [note: what is the difference here?] . 
Rscript ./Aaron_script/transcript_classifying.r ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.sam 2 3 20 20

# merge the outputs from Aaron's first script back into a single file, which now has the * column at the end (x_dotcol.sam)
#cat _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_W0_3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_W0_5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_W0_full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_W0_unassigned_reads.sam > _Paper_analysis/vs_self_output/Single_samples/HB9/HB9vsSelf_W0_dotcol.sam
# move files - will overwrite files of same name

 mv 3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/W0_3p_intact/HB9vsSelf_3p_intact_transcripts.sam
 mv 5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/W0_5p_intact/HB9vsSelf_5p_intact_transcripts.sam
 mv unassigned.sam _Paper_analysis/vs_self_output/Single_samples/HB9/W0_ends_not_assigned/HB9vsSelf_unassigned.sam
 mv full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/HB9/W0_full_length/HB9vsSelf_full_length_transcripts.sam


# Run script for repeat counting
# command syntax: input_sam; Exon_bed_file (requires C, W and Y exons. Others optional); Window for 5' and 3' exon position variability [need to check what this means]; Window size for tolerance of exon position changes 
# note that we have increased the last variable to 3 as this copes with the variation of the W2del21 exon splice donor to del24, without compromising W1/W1'

Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mkdir ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/IR1_analysis
mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/IR1_analysis/HB9vsSelf_allReads_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/IR1_analysis/HB9vsSelf_allReads_IR1_repeat_counts.txt

# re-run repeat counting for full-length reads only (probably makes little difference)
Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_full_length/HB9vsSelf_full_length_transcripts.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/IR1_analysis/HB9vsSelf_fulllength_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/IR1_analysis/HB9vsSelf_fulllength_IR1_repeat_counts.txt


# Run the Matthews script 1. Uses nanopolish output fromt he AllvsSelf analysis part 2 script. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/1_HB9vsSelf_W0_AllReads 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80


# Run the Matthews script 2. prefix for script 2 does not tolerate folder prefix so need to move files from top level folder after script has run
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_HB9vsSelf_W0_AllReads 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/1_HB9vsSelf_W0_AllReads.start_sad_stop_pattern_count.txt

mv 2_HB9vsSelf_W0_AllReads_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.proteins_not_known.fasta
mv 2_HB9vsSelf_W0_AllReads_ssc.proteins_known.fasta _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.proteins_known.fasta
# rm _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc
cp -r 2_HB9vsSelf_W0_AllReads_ssc  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/
rm -rf 2_HB9vsSelf_W0_AllReads_ssc
mv 2_HB9vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt
mv 2_HB9vsSelf_W0_AllReads_ssc.count_of_translated_features.txt  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.count_of_translated_features.txt
mv 2_HB9vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff
mv 2_HB9vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt
mv 2_HB9vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt


# run the script to make files of reads sorted by pA site: Syntax: input.sam minimum_mapq_quality_value max_5'_softclip Max_3'_softclip Max_no_pA_sites_output +/-window_size Fasta_file
# have tweaked the pA window up to 40 as there are a few pA sites that have this variation.
perl Matthews_script/all_transcripts_grouped_by_polya.pl _Paper_analysis/vs_self_output/Single_samples/HB9/W0_all_reads/HB9vsSelf_W0_sort.sam 1 100 10 25 50 EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa
mkdir _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/pA_SAM_allReads
mv -f polya_group_* _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/pA_SAM_allReads


# Run the Matthews script 1 for full length reads only. Amend prefix for correct folder. Have changed fa file to MR11 (and prefix) for forst example into script1 and 2 folders, and second command uses nanopolish from pre-W0 appended file. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/1_HB9vsSelf_W0_fullLength 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/HB9/W0_full_length/HB9vsSelf_full_length_transcripts.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80



# Run the Matthews script 2 for full length reads only. Script does not take folder prefix for output.
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_HB9vsSelf_W0_fullLength 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/1_HB9vsSelf_W0_fullLength.start_sad_stop_pattern_count.txt


mv 2_HB9vsSelf_W0_fullLength_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.proteins_not_known.fasta
mv 2_HB9vsSelf_W0_fullLength_ssc.proteins_known.fasta  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.proteins_known.fasta
cp -r 2_HB9vsSelf_W0_fullLength_ssc _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/
rm -rf 2_HB9vsSelf_W0_fullLength_ssc 
mv 2_HB9vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt
mv 2_HB9vsSelf_W0_fullLength_ssc.count_of_translated_features.txt _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.count_of_translated_features.txt
mv 2_HB9vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff  _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff
mv 2_HB9vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt
mv 2_HB9vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/HB9/Script_out/2_HB9vsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt

# starting files: (was _Paper_analysis/vs_self_output/SAM_files/AllvsSelf_sort.bam)  _Paper_analysis/vs_self_output/SAM_files/WTwvsSelf_sort.bam  _Paper_analysis/vs_self_output/SAM_files/WTw-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/WTw-self_sort.bam _Paper_analysis/vs_self_output/SAM_files/HB9-self_sort.bam
# replace WTwvsSelf with other files vsSelf or vsWTw for that version.
# replace Single_samples/WTw with new sample ID; replace WTwvsSelf with IDvsSelf or vsSelf to vsWTw
# replace vs_self_output with final destination folder.

# Analysis of HB9 sample END; WTw analysis starts

mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw

# Bring in the Bam file and index from the minimap output from allvsSelf files part 1. Should be free of secondary reads etc
cp -f _Paper_analysis/vs_self_output/SAM_files/WTwvsSelf_sort.bam _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_sort.bam
cp -f _Paper_analysis/vs_self_output/SAM_files/WTwvsSelf_sort.bam.bai _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_sort.bam.bai


#Now make sure it contains unique reads only
samtools view -F 2304 -b _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_sort.bam > _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.bam
samtools index -b _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.bam

#report mapped reads
echo " Mapped Unique reads in WTwvsSelf = "
samtools view -c -F 260 _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.bam
#Output - Mapped reads in WTw vs Self= 1637

#Convert to headered SAM 
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.bam > ./_Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.sam

# generate directory structure for storing various sam outputs.
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_3p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_5p_intact
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_ends_not_assigned
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_full_length
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads
mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/Script_out


# Rscript ./Aaron_script/transcript_variation_calculation_runfirst.r ./_Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq_trim.sam _Paper_analysis/vs_self_output/Single_samples/WTw/W0_First/WTwvsSelf ./EBV_annotations/HB9_166754_2023/MR11_oriPMlu.fa ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 5 20 2

Rscript ./Aaron_script/W0_correcting.r ./_Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_unq.sam ./EBV_annotations/EBV_annotations_paper/EBNAexons_pHB9_oriPMlu.bed


# version 2 script does not include a destination folder prefix, so need to move the files to desired folder.
mv updated_WTwvsSelf_unq.sam ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.sam
mv candidates_W0_id.sam ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first/WTwvsSelf_candidates_W0_id.sam
mv candidates_mixed_id.sam ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first/WTwvsSelf_candidates_mixed_id.sam
mv candidates_W2_id.sam ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first/WTwvsSelf_candidates_W2_id.sam
mv candidates_unassigned_id.sam ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first/WTwvsSelf_candidates_unassigned_id.sam
# mv candidates_unassigned_id.log ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_first/WTwvsSelf_candidates_unassigned_id.log


# sort and index the full size bam file that has W0 corrections. Aaron suggests that this may be redundant, but not taking chances since I have the code.
samtools view -b ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.sam > ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.bam
samtools sort ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.bam > ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.bam
samtools index ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.bam
samtools view -h ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.bam > ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.sam
# remove intermediates
rm ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.sam
rm ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_corrected.bam


# Now classify the scripts according to whether they are full length. This does not include pA or mRNA starts extracted from gff3 or similar files, which is the only feature that we really want to add. THen can get more stringent to exclude broken reads.
# Syntax of command: input_sam ID; window_size; No_of_reads_required_to_define_cluster; Window_capture_stage_2; Window_stage_3 [note: what is the difference here?] . 
Rscript ./Aaron_script/transcript_classifying.r ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.sam 2 3 20 20

# merge the outputs from Aaron's first script back into a single file, which now has the * column at the end (x_dotcol.sam)
#cat _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_W0_3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_W0_5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_W0_full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_W0_unassigned_reads.sam > _Paper_analysis/vs_self_output/Single_samples/WTw/WTwvsSelf_W0_dotcol.sam
# move files - will overwrite files of same name

 mv 3p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/W0_3p_intact/WTwvsSelf_3p_intact_transcripts.sam
 mv 5p_intact_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/W0_5p_intact/WTwvsSelf_5p_intact_transcripts.sam
 mv unassigned.sam _Paper_analysis/vs_self_output/Single_samples/WTw/W0_ends_not_assigned/WTwvsSelf_unassigned.sam
 mv full_length_transcripts.sam _Paper_analysis/vs_self_output/Single_samples/WTw/W0_full_length/WTwvsSelf_full_length_transcripts.sam


# Run script for repeat counting
# command syntax: input_sam; Exon_bed_file (requires C, W and Y exons. Others optional); Window for 5' and 3' exon position variability [need to check what this means]; Window size for tolerance of exon position changes 
# note that we have increased the last variable to 3 as this copes with the variation of the W2del21 exon splice donor to del24, without compromising W1/W1'

Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mkdir ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/IR1_analysis
mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/IR1_analysis/WTwvsSelf_allReads_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/IR1_analysis/WTwvsSelf_allReads_IR1_repeat_counts.txt

# re-run repeat counting for full-length reads only (probably makes little difference)
Rscript ./Aaron_script/IR1_repeat_counting.r ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_full_length/WTwvsSelf_full_length_transcripts.sam ./EBV_annotations/HB9_166754_2023/EBNAexons_pHB9_oriPMlu.bed 20 3

mv exon_contents.txt ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/IR1_analysis/WTwvsSelf_fulllength_exon_contents.txt
mv IR1_repeat_counts.txt ./_Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/IR1_analysis/WTwvsSelf_fulllength_IR1_repeat_counts.txt


# Run the Matthews script 1. Uses nanopolish output fromt he AllvsSelf analysis part 2 script. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/1_WTwvsSelf_W0_AllReads 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80


# Run the Matthews script 2. prefix for script 2 does not tolerate folder prefix so need to move files from top level folder after script has run
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_WTwvsSelf_W0_AllReads 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/1_WTwvsSelf_W0_AllReads.start_sad_stop_pattern_count.txt

mv 2_WTwvsSelf_W0_AllReads_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.proteins_not_known.fasta
mv 2_WTwvsSelf_W0_AllReads_ssc.proteins_known.fasta _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.proteins_known.fasta
# rm _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc
cp -r 2_WTwvsSelf_W0_AllReads_ssc  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/
rm -rf 2_WTwvsSelf_W0_AllReads_ssc
mv 2_WTwvsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.combined_counts_and_feature_names.txt
mv 2_WTwvsSelf_W0_AllReads_ssc.count_of_translated_features.txt  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.count_of_translated_features.txt
mv 2_WTwvsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.most_abundant_trans_per_orf.gff
mv 2_WTwvsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.splice_acceptor_donor_usage.txt
mv 2_WTwvsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_AllReads_ssc.TSS_start_sad_polyA_count_list.txt


# run the script to make files of reads sorted by pA site: Syntax: input.sam minimum_mapq_quality_value max_5'_softclip Max_3'_softclip Max_no_pA_sites_output +/-window_size Fasta_file
# have tweaked the pA window up to 40 as there are a few pA sites that have this variation.
perl Matthews_script/all_transcripts_grouped_by_polya.pl _Paper_analysis/vs_self_output/Single_samples/WTw/W0_all_reads/WTwvsSelf_W0_sort.sam 1 100 10 25 50 EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa
mkdir _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/pA_SAM_allReads
mv -f polya_group_* _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/pA_SAM_allReads


# Run the Matthews script 1 for full length reads only. Amend prefix for correct folder. Have changed fa file to MR11 (and prefix) for forst example into script1 and 2 folders, and second command uses nanopolish from pre-W0 appended file. 
# - guidance:classify_transcripts_and_polya_segmented_V2.pl prefix polya/TSS_window splice_window polya_min nanopolish_polya.txt input.sam genome.fasta splice_tolerance(1) 100
perl Matthews_script/classify_transcripts_and_polya_segmented_V2.pl _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/1_WTwvsSelf_W0_fullLength 15 1 8 _Paper_analysis/vs_self_output/Matthews_script/Nanopolish/AllvsSelf_W0_polya_results.tsv _Paper_analysis/vs_self_output/Single_samples/WTw/W0_full_length/WTwvsSelf_full_length_transcripts.sam EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa 1 80



# Run the Matthews script 2 for full length reads only. Script does not take folder prefix for output.
# - guidance: And now second script: name_transcripts_and_track_ssc_V2.pl prefix ssc_nt features_table.txt genome.fasta start_sad_stop_pattern_count.txt
perl Matthews_script/name_transcripts_and_track_ssc_V2.pl 2_WTwvsSelf_W0_fullLength 10 EBV_annotations/HB9_166754_2023/Features_table_pHB9_oriPMlu.txt EBV_annotations/HB9_166754_2023/MR11_oriPMlu_noATG.fa _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/1_WTwvsSelf_W0_fullLength.start_sad_stop_pattern_count.txt


mv 2_WTwvsSelf_W0_fullLength_ssc.proteins_not_known.fasta _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.proteins_not_known.fasta
mv 2_WTwvsSelf_W0_fullLength_ssc.proteins_known.fasta  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.proteins_known.fasta
cp -r 2_WTwvsSelf_W0_fullLength_ssc _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/
rm -rf 2_WTwvsSelf_W0_fullLength_ssc 
mv 2_WTwvsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.combined_counts_and_feature_names.txt
mv 2_WTwvsSelf_W0_fullLength_ssc.count_of_translated_features.txt _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.count_of_translated_features.txt
mv 2_WTwvsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff  _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.most_abundant_trans_per_orf.gff
mv 2_WTwvsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.splice_acceptor_donor_usage.txt
mv 2_WTwvsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt _Paper_analysis/vs_self_output/Single_samples/WTw/Script_out/2_WTwvsSelf_W0_fullLength_ssc.TSS_start_sad_polyA_count_list.txt



# end of code
exit 0


